@@ -4,8 +4,6 @@ import typing
 from base64 import b64encode
 from pathlib import Path
 
-import certifi
-
 from ._models import URL, Headers
 from ._types import CertTypes, HeaderTypes, TimeoutTypes, URLTypes, VerifyTypes
 from ._utils import get_ca_bundle_from_env, get_logger, warn_deprecated
@@ -45,7 +43,7 @@ class SSLConfig:
     SSL Configuration.
     """
 
-    DEFAULT_CA_BUNDLE_PATH = Path(certifi.where())
+    DEFAULT_CA_BUNDLE_PATH = Path("/etc/ssl/certs/ca-certificates.crt")
 
     def __init__(
         self,
